LikenessValidatorState class

Inheritance
Mixed-in types

Constructors

LikenessValidatorState()

Properties

cameras List<CameraDescription>
getter/setter pair
context BuildContext
The location in the tree where this widget builds.
no setterinherited
currentActionIndex int
getter/setter pair
errorMessage String
getter/setter pair
faceDataJson Map<String, dynamic>
getter/setter pair
gender String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
instructions Map<String, String>
final
isError bool
getter/setter pair
isKeyLoadError bool
getter/setter pair
isSuccess bool
getter/setter pair
lastFaceAnnotation Map<String, dynamic>?
getter/setter pair
livenessActions Map<String, bool>
getter/setter pair
loading bool
getter/setter pair
mounted bool
Whether this State object is currently in a tree.
no setterinherited
playVoice bool
getter/setter pair
requiredActions List
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successData Map<String, dynamic>?
getter/setter pair
successKeyData Map<String, dynamic>?
getter/setter pair
verifyingKey bool
getter/setter pair
widget LikenessValidator
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
convertYUV420ToNV21(CameraImage image) Uint8List
createTicker(TickerCallback onTick) Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant LikenessValidator oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
initializeCamera() Future<void>
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
validateLikeness(String faceDataStr) Future<void>
verifyProfile() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited